pyqode.python package
=====================

Subpackages
-----------

.. toctree::

    pyqode.python.backend
    pyqode.python.managers
    pyqode.python.modes
    pyqode.python.panels
    pyqode.python.widgets

Submodules
----------

pyqode.python.folding module
----------------------------

.. automodule:: pyqode.python.folding
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pyqode.python
    :members:
    :undoc-members:
    :show-inheritance:
